'use strict';

/* If your code uses external modules, create instances here. - 外部モジュールを使う場合はここでインスタンスを生成してください。
   e.g.  const request = require('xxxx');   // xxxx : external module - xxxxは外部モジュール */
const axios = require('axios');

const apiHost = 'https://api.worldweatheronline.com/premium/v1/weather.ashx';
const apiKey = '----------Your API Key----------'; /* Your API key */
const format = 'json';
const timePeriod = '1';
const numsOfDay = '1';
const forecastIn24Hour = 'no';
const includeLocation = 'no';
const monthlyCalculation = 'no';
const forecast = 'no';
const currentCondition = 'yes';
const showMapUrl = 'no';
let urlString = '';

exports.handler = async event => {

  if (event.call === 'lambda') {
    console.log('CALLED:LAMBDA');
    /* 
     Code for "warm start"
    The Riiiver system might call your Lambda function constantly to make it Warm Start.
    When the system called your function, the heavy modules are cached on the Lamba environment.
    The following code makes the (heavy) external module cached.
     ピースの実行速度高速化処理
    Lambda関数をウォームスタート状態にするために、このLambda関数は
    定期的にRiiiver System側からコールされることがあります。その際の処理をここで記述します。
    外部モジュールなどの重いインスタンスをキャッシュさせ、高速化します。*/
    if (axios !== null) { }

    return;
  }
   
  /* Start coding here - これ以降にコードを記入してください。*/
  console.log('Thermometer Request:', JSON.stringify(event));

  // Get the location information entered by the user - ユーザの位置情報を取得する。
  const latitude      = event.properties.parameters.location.latitude;
  const longitude     = event.properties.parameters.location.longitude;

  if (latitude === undefined || longitude === undefined) {
    throw Error('Location information is missing');
  } 

  // Combine strings and make the URL - URLの文字列を完成させる。
  let urlString = `${apiHost}?q=${latitude},${longitude}&format=${format}&key=${apiKey}&tp=${timePeriod}&num_of_days=${numsOfDay}&fx24=${forecastIn24Hour}&includelocation=${includeLocation}&mca=${monthlyCalculation}&fx=${forecast}&cc=${currentCondition}&showmap=${showMapUrl}&timestamp=${new Date().getTime()}`;
  console.log(urlString);

  const options = {
    method: 'get',
    url: urlString,
  };

  let weatherData = await getWeatherInfo(options);

  if (weatherData) {
    var info = weatherData.data.current_condition[0].temp_C;
  }
  
  console.log('Output : ', info);

  let response = {
    status: 200,
    body: { temperature: info }
  };
  console.log('responde : ', response);
  return response;
}

function getWeatherInfo(options) {
  return axios.request(options)
    .then(function (response) {
      console.log(JSON.stringify(response.data));
      return response.data;
    })
    .catch(function (error) {
      console.error('getWeatherInfo: response = ', (error));
      return null;
    })
}

